@@ -15,7 +15,7 @@ NULL
 #' column labels if specified value is true. The default value is false.
 #' @param rowlabels Vector specifying the class of rows. The class number starts from zero. Provide -1 for unknown row class. 
 #' @param collabels Vector specifying the class of columns. The class number starts from zero. Provide -1 for unknown column class.
-#' @param model This is the name of model. The following models exists for various types of data:
+#' @param model This is the name of model. The following models exists for Gaussian data:
 #' \tabular{rlll}{
 #'     Model  \tab Data-type \tab Proportions \tab Dispersion/Variance \cr
 #'     pik_rhol_sigma2kl(Default) \tab continuous \tab unequal \tab unequal \cr
@@ -58,21 +58,21 @@ coclusterContinuous<-function( data, semisupervised = FALSE
 {
 	#Check for data and get dimensions
 	if(missing(data)){ stop("Data is missing.")}
-	if(!is.list(data))
+  if(!is.list(data))
   {
-		if(!is.matrix(data)) { stop("Data should be matrix.")}
-    dimention = dim(data)
-	}
+    if(!is.matrix(data)) { stop("Data should be matrix.")}
+    dimData = dim(data)
+  }
   else
-	{
-		if(!is.matrix(data[[1]])) {	stop("Data should be matrix.")}
-		if(!is.numeric(data[[2]])||!is.numeric(data[[3]]))
-    {	stop("Row/Column effects should be numeric vectors.")}
-		if(length(data[[2]])!=dim(data[[1]])[1]||length(data[[3]])!=dim(data[[1]])[2])
-    {	stop("Dimension mismatch in Row/column effects  and Data.")}
-    dimention = dim(data[[1]])
-	}
-    
+  {
+    if(!is.matrix(data[[1]])) { stop("Data should be matrix.")}
+    if(!is.numeric(data[[2]])||!is.numeric(data[[3]]))
+    { stop("Row/Column effects should be numeric vectors.")}
+    if(length(data[[2]])!=dim(data[[1]])[1]||length(data[[3]])!=dim(data[[1]])[2])
+    { stop("Dimension mismatch in Row/column effects  and Data.")}
+    dimData = dim(data[[1]])
+  }
+  
   #check for row and column labels
   if (semisupervised)
   {
@@ -83,22 +83,22 @@ coclusterContinuous<-function( data, semisupervised = FALSE
     if(!missing(collabels)&&!is.numeric(collabels))
       stop("Column labels should be a numeric vector.")
     
-    if(missing(rowlabels))      rowlabels = rep(-1,dimention[1])
-    else if(missing(collabels)) collabels = rep(-1,dimention[2])
+    if(missing(rowlabels))      rowlabels = rep(-1,dimData[1])
+    else if(missing(collabels)) collabels = rep(-1,dimData[2])
     
-    if(dimention[1]!=length(rowlabels))
+    if(dimData[1]!=length(rowlabels))
       stop("rowlabels length does not match number of rows in data (also ensure to put -1 in unknown labels)")
     
-    if(dimention[2]!=length(collabels))
+    if(dimData[2]!=length(collabels))
       stop("collabels length does not match number of columns in data (also  ensure to put -1 in unknown labels)")
   }
 	#check for number of coclusters
-	if(missing(nbcocluster))
-	{ stop("Mention number of CoClusters.")}
-  
-	if(dimention[1]<nbcocluster[1]) stop("Number of Row cluters exceeds numbers of rows.")
-	if(dimention[2]<nbcocluster[2])	stop("Number of Column cluters exceeds numbers of columns.")
-	#check for Algorithm name (and make it compatible with version 1)
+  if(missing(nbcocluster))     { stop("Mention number of CoClusters.")}
+  if(dimData[1]<nbcocluster[1]){ stop("Number of Row clusters exceeds numbers of rows.")}
+  if(dimData[2]<nbcocluster[2]){ stop("Number of Column clusters exceeds numbers of columns.")}
+  if(nbcocluster[1]<1 || nbcocluster[2]<1) { stop("Number of cluster must be at least 1.")}
+
+  #check for Algorithm name (and make it compatible with version 1)
 	if(strategy@algo=="XEMStrategy")
   {
     warning("The algorithm 'XEMStrategy' is renamed as BEM!")
@@ -127,17 +127,19 @@ coclusterContinuous<-function( data, semisupervised = FALSE
     }
   }
 	# checking for strategy
-	if(length(strategy@initmethod)==0)
-	{strategy@initmethod = "emInitStep"}
-	else
-	{
-		if(strategy@initmethod!="cemInitStep" && strategy@initmethod!="emInitStep")
-			stop("In coclusterContinuous. Incorrect initialization method, valid method(s) are: cemInitStep, emInitStep")
-	}
+	if(length(strategy@initmethod)==0) {strategy@initmethod = "emInitStep"}
+  ## else
+  ## {
+  ##   if(strategy@initmethod!="cemInitStep" && strategy@initmethod!="emInitStep")
+  ##     stop("In coclusterContinuous. Incorrect initialization method, valid method(s) are: cemInitStep, emInitStep")
+  ## }
 	#  check nbCore
 	if(!is.numeric(nbCore) && length(nbCore) != 1) stop("nbCore must be an integer")
-  inpobj<-new("ContinuousOptions",data = data,rowlabels = rowlabels, collabels = collabels, semisupervised = semisupervised, 
-                  datatype = "continuous", model = model,nbcocluster = nbcocluster,strategy = strategy)
+  inpobj<-new( "ContinuousOptions",data = data
+             , rowlabels = rowlabels, collabels = collabels
+             , semisupervised = semisupervised
+             , datatype = "continuous"
+             , model = model, nbcocluster = nbcocluster, strategy = strategy)
 
   .Call("CoClustmain",inpobj, nbCore,PACKAGE = "blockcluster")
   cat(inpobj@message,"\n")
